API Reference
=============

Classes
-------

.. currentmodule:: scitacean

Main Classes
~~~~~~~~~~~~

.. autosummary::
   :toctree: ../generated/classes
   :template: scitacean-class-template.rst
   :recursive:

   Client
   Dataset
   File
   pid.PID

File Transfer
~~~~~~~~~~~~~

.. autosummary::
   :toctree: ../generated/classes
   :template: scitacean-class-template.rst
   :recursive:

   transfer.ess.ESSTestFileTransfer

Dataclasses
~~~~~~~~~~~

.. currentmodule:: scitacean._dataset_fields

.. autosummary::
   :toctree: ../generated/classes
   :template: scitacean-dataclass-template.rst
   :recursive:

   DatasetFields

Typing
~~~~~~

.. currentmodule:: scitacean

.. autosummary::
   :toctree: ../generated/classes
   :template: scitacean-class-template.rst
   :recursive:

   typing.Downloader
   typing.DownloadConnection
   typing.FileTransfer
   typing.UploadConnection
   typing.Uploader

Testing
~~~~~~~

.. currentmodule:: scitacean

.. autosummary::
   :toctree: ../generated/classes
   :template: scitacean-class-template.rst
   :recursive:

   testing.client.FakeClient
   testing.transfer.FakeFileTransfer
